using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Data.OleDb;
using System.Data.SqlClient;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Configuration;

namespace WindowsApplication1
{
    public partial class Form1 : Form
    {
        private DataSet ds;
        private OleDbCommand dcom;
        private OleDbDataAdapter da;
        private FarPoint.Win.Spread.FpSpread fpSpread1;
        private FarPoint.Win.Spread.SheetView fpSpread1_Sheet1;
        private FarPoint.Win.Spread.SheetView curSheet;
		
        
        public Form1()
        {
            InitializeComponent();
            AppInfo.Initialize();
            
        }

        private void button2_Click(object sender, EventArgs e)
        {
            FarPoint.Win.Spread.SheetView curSheet = fpSpread1.Sheets[0];
            curSheet.Rows.Add(curSheet.RowCount, 1);
            curSheet.SetActiveCell(curSheet.RowCount - 1, 0, true);
            fpSpread1.Focus();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            FarPoint.Win.Spread.SheetView curSheet = fpSpread1.Sheets[0];
            if (curSheet.IsSelected(curSheet.ActiveRowIndex, curSheet.ActiveColumnIndex))
            {
                if (MessageBox.Show("Are you sure you want to delete selected row?", "Confirm", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                {
                    curSheet.ActiveRow.Remove();
                    SaveChanges();
                }
            }
            else
                MessageBox.Show("To delete, please select a row by clicking on the first column of desired row.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Information);
        }

        private void button3_Click(object sender, EventArgs e)
        {
            if (ds.HasChanges())
            {
                if (SaveChanges())
                    MessageBox.Show("Records have been saved", "Save", MessageBoxButtons.OK, MessageBoxIcon.Information);
            }
            else
            {
                MessageBox.Show("No changes made that needs to be saved", "Save Records");
            }
        }

        private void button4_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private bool SaveChanges()
        {
            DataModel dm = new DataModel();
            OleDbConnection DbCon = dm.GetConnection;

            fpSpread1.Hide();
            btnSave.Focus();
            bool retValue = true;
            try
            {
                Cursor.Current = Cursors.WaitCursor;

                dcom = new OleDbCommand();
                dcom.Connection = DbCon;

                //create the insert/delete/update statements
                OleDbCommandBuilder cb = new OleDbCommandBuilder(da);

                //retrieve the changed rows
                DataSet dsChanges = ds.GetChanges();

                if (dsChanges != null)
                {
                    //update the database
                    da.Update(dsChanges);

                    //accept the changes within the dataset
                    ds.AcceptChanges();

                    dataGridFormat();
                }

                fpSpread1.Show();

                Cursor.Current = Cursors.Default;
            }
            catch (Exception excep)
            {
                Cursor.Current = Cursors.Default;
                //error occurs, show messages

                fpSpread1.Show();

                MessageBox.Show(excep.ToString());

                retValue = false;
            }
            finally
            {
                if (DbCon != null)
                    DbCon.Close();

                if (dm != null)
                    dm.CloseDB();
            }
            return retValue;
        }

        private void GridData()
        {
            DataModel dm = new DataModel();
            try
            {
                Cursor.Current = Cursors.WaitCursor;
                curSheet = fpSpread1.Sheets[0];
                curSheet.Reset();
                curSheet.AutoGenerateColumns = true;
                curSheet.DataAutoSizeColumns = true;
                curSheet.DataAutoCellTypes = true;
                curSheet.RowHeaderColumnCount = 1;
                curSheet.AlternatingRows[0].BackColor = Color.LightCyan;
                curSheet.SetColumnAllowAutoSort(0, curSheet.ColumnCount, true);

                da = new OleDbDataAdapter("SELECT AssetClassCode, AssetClassName, AssetClassLongName, AssetClassSeq from tblAssetClass ORDER BY AssetClassSeq,AssetClassName", AppInfo.ConnectionString);
                ds = new DataSet();
                ds = dm.ExecuteDataSet(da);

                // add handlers
                //da.RowUpdated += new OleDbRowUpdatedEventHandler(da_RowUpdated);

                fpSpread1.DataSource = ds.Tables[0];
                fpSpread1.Refresh();

                Cursor.Current = Cursors.Default;
            }
            catch (Exception excep)
            {
                Cursor.Current = Cursors.Default;
                MessageBox.Show(excep.ToString());
            }
            finally
            {
                if (dm != null)
                    dm.CloseDB();
            };
        }


        private void dataGridFormat()
        {
            fpSpread1.EditModeReplace = true;
            fpSpread1.HorizontalScrollBarPolicy = FarPoint.Win.Spread.ScrollBarPolicy.AsNeeded;
            fpSpread1.VerticalScrollBarPolicy = FarPoint.Win.Spread.ScrollBarPolicy.AsNeeded;

            FarPoint.Win.Spread.CellType.NumberCellType numCell = new FarPoint.Win.Spread.CellType.NumberCellType();
            numCell.DecimalPlaces = 0;
            numCell.NegativeRed = true;

            FarPoint.Win.Spread.CellType.TextCellType txt = new FarPoint.Win.Spread.CellType.TextCellType();
            txt.CharacterCasing = CharacterCasing.Upper;
            txt.CharacterSet = FarPoint.Win.Spread.CellType.CharacterSet.Ascii;
            txt.MaxLength = 20;

            FarPoint.Win.Spread.CellType.CurrencyCellType currencyCell2 = new FarPoint.Win.Spread.CellType.CurrencyCellType();
            currencyCell2.ShowCurrencySymbol = true;
            currencyCell2.ShowSeparator = true;
            currencyCell2.NegativeRed = true;
            currencyCell2.NegativeFormat = FarPoint.Win.Spread.CellType.CurrencyNegativeFormat.ParenthesesSymbolBefore;
            currencyCell2.DecimalPlaces = 2;

            curSheet.Columns[0].DataField = "AssetClassCode";
            curSheet.ColumnHeader.Columns[0].Label = "Class\nCode";
            curSheet.Columns[0].AllowAutoSort = true;
            curSheet.Columns[0].CellType = txt;

            curSheet.Columns[1].DataField = "AssetClassName";
            curSheet.ColumnHeader.Columns[1].Label = "Class Name";
            curSheet.Columns[1].Visible = true;
            curSheet.Columns[1].AllowAutoSort = true;

            curSheet.Columns[2].DataField = "AssetClassLongName";
            curSheet.Columns[2].Label = "Class Long Name";

            curSheet.Columns[3].DataField = "AssetClassSeq";
            curSheet.Columns[3].Label = "Display\nSequence";
            curSheet.Columns[3].CellType = numCell;

            //Asset code and Asset class name of a field are different then show Asset class name as row header
            //showRowHeader();

            curSheet.ColumnHeader.Rows[0].Height = 30;
            //Util.SetColumnWidth(fpSpread1.Sheets[0]);

            fpSpread1.Show();
        }

        private void showRowHeader()
        {
            int rowcount = 0;
            foreach (DataRow dRow in ds.Tables[0].Rows)
            {
                if (dRow["AssetClassCode"].Equals(dRow["AssetClassName"]))
                {
                    int rowLabel = rowcount + 1;
                    curSheet.Rows[rowcount].Label = rowLabel.ToString();
                }
                else
                {
                    curSheet.Rows[rowcount].Label = dRow["AssetClassName"].ToString();
                }
                rowcount = rowcount + 1;
            };

            curSheet.RowHeader.Columns[0].Width = curSheet.RowHeader.Columns[0].GetPreferredWidth();

        }

        private void Form1_Load(object sender, EventArgs e)
        {
            GridData();
            dataGridFormat();
        }

    }

	public class DataModel
	{
		private  string m_connStr = "";

		private  OleDbConnection m_dbConnection;
		private  OleDbCommand m_command;
		private  OleDbDataReader m_reader;
		private  OleDbDataAdapter m_DataAdapter;
		private  OleDbTransaction m_Transaction;
		private  DataSet m_DataSet;
		private  DataTable m_DataTable;

		private const int COMMAND_TIMEOUT = 300;

		public DataModel()
		{			
			try
			{
				//open DB connection
				//m_connStr = "Provider=Microsoft.Jet.OleDb.4.0; Data Source=" + getAppPath() + "db\\rebalance.mdb;";
				m_connStr = AppInfo.ConnectionString;
				m_dbConnection = new OleDbConnection(m_connStr);
				m_dbConnection.Open();	
				
			}
			catch(OleDbException sqlException)
			{
				throw (sqlException);
			}
		}

		/// <summary>
		/// Function Name : GetConnection
		/// <param>       : </param>
		/// <returns>     : OleDbConnection</returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function is used to return connection
		/// Modifications : 
		/// </summary>

		public OleDbConnection GetConnection
		{
			get
			{
				return m_dbConnection; 
			}
		}

		public OleDbTransaction BeginTransaction()
		{
			try
			{
				if (m_dbConnection != null)
					m_Transaction = m_dbConnection.BeginTransaction();
			}
			catch(OleDbException sqlException)
			{
				//destroy command object if open
				if (m_Transaction !=null)
				{
					m_Transaction.Rollback();
					m_Transaction = null;
				}
				throw (sqlException);				
			}
			return m_Transaction;
		}

		public void CommitTransaction()
		{
			try
			{
				if (m_dbConnection != null && m_Transaction != null)
				{
					m_Transaction.Commit();
				}
				m_Transaction = null;
			}
			catch(OleDbException sqlException)
			{
				//destroy command object if open
				if (m_Transaction !=null)
				{
					m_Transaction.Rollback();
					m_Transaction = null;
				}
				throw (sqlException);				
			}
		}

		public void RollbackTransaction()
		{
			try
			{
				if (m_dbConnection != null && m_Transaction != null)
				{
					m_Transaction.Rollback();
				}
				m_Transaction = null;
			}
			catch
			{
				m_Transaction = null;
			}

		}

		/// <summary>
		/// Function Name : ExecuteReader
		/// <param>       : string strSQL</param>
		/// <returns>     : OleDbDataReader</returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function is used to return the OleDb data reader
		///					on executing the sql string
		/// Modifications : 
		/// </summary>
		
		public  OleDbDataReader ExecuteReader(string strSQL) 
		{
			//close reader and command if already open
			if (m_reader !=null)
				m_reader.Close();			
			if (m_command !=null)
				m_command.Dispose();
			
			try
			{
				//create command object
				m_command = new OleDbCommand(strSQL,m_dbConnection);
				//execute command and get reader
				m_reader = m_command.ExecuteReader();
			}
			catch(OleDbException sqlException)
			{
				if (m_reader !=null)
					m_reader.Close();			
				if (m_command !=null)
					m_command.Dispose();

				throw (sqlException);
			}
			
			//return reader
			return m_reader;
		}
		
		public  OleDbDataReader ExecuteReader(string strSQL, OleDbCommand command) 
		{
			//close reader and command if already open
			if (m_reader !=null)
				m_reader.Close();			

			try
			{
				//execute command and get reader
				command.CommandText = strSQL;
				command.Connection = m_dbConnection;
				m_reader = command.ExecuteReader();
			}
			catch(OleDbException sqlException)
			{
				throw (sqlException);
			}
			
			//return reader
			return m_reader;
		}


		public OleDbDataReader ExecuteReader(OleDbCommand command) 
		{
			//close reader and command if already open
			if (m_reader !=null)
				m_reader.Close();			

			try
			{
				//execute command and get reader
				//command.CommandText = strSQL;
				command.Connection = m_dbConnection;
				m_reader = command.ExecuteReader();
			}
			catch(OleDbException sqlException)
			{
				throw (sqlException);
			}
			
			//return reader
			return m_reader;
		}


		public byte[] GetCompanyLogo()
		{
			SqlConnection conn =null;
			SqlCommand cmd = null;
			SqlDataReader dr=null;
			byte[] result=null;

			try
			{
				//
				// Connecting to database.
				//
				conn = new SqlConnection(AppInfo.SqlConnectionString);
				cmd = new SqlCommand("DownloadFile",conn);
				cmd.CommandType	= System.Data.CommandType.StoredProcedure;
				// ----------------------------------------------

				//
				// Opening the connection and executing the command.
				//  The idea behind using a dataReader is that, on the SQL Server, we cannot assign to a
				// variable the value of an image field. So, we use a querry to select the record we want 
				// and we use a datareader to read that query.
				//  Because we are returnig information based on a primary key, we are always returning
				// only one row of data.
				//
				conn.Open();
				dr = cmd.ExecuteReader();
				dr.Read();
				//
				// We are casting the value returned by the datareader to the byte[] data type.
				//
				result = (byte[])dr.GetValue(0);

				//
				// Closing the datareader and the connection
				//
				dr.Close();
				conn.Close();
				// ------------------------------------------

				//
				// Disposing of the objects so we don't occupy memory.
				//
				conn.Dispose();
				cmd.Dispose();
				// ------------------------------------------
			}
			catch(Exception	e)
			{
				//
				// If an error occurs, we assign null to the result and display the error to the user,
				// with information about the StackTrace for debugging purposes.
				//
				throw (e);
			}
			return result;				
		}



		/// <summary>
		/// Function Name : ExecuteSingleRowReader
		/// <param>       : string strSQL</param>
		/// <returns>     : OleDbDataReader</returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function is used to return the OleDb data reader
		///					on executing the sql string
		/// Modifications : 
		/// </summary>
		public  OleDbDataReader ExecuteSingleRowReader(string strSQL) 
		{
			//close reader and command if already open
			if (m_reader !=null)
				m_reader.Close();			
			if (m_command !=null)
				m_command.Dispose();
			
			try
			{
				//create command object
				m_command = new OleDbCommand(strSQL,m_dbConnection);
				//execute command and get reader
				m_reader = m_command.ExecuteReader(System.Data.CommandBehavior.SingleRow);
			}
			catch(OleDbException sqlException)
			{
				if (m_reader !=null)
					m_reader.Close();			
				if (m_command !=null)
					m_command.Dispose();

				throw (sqlException);
			}
			
			//return reader
			return m_reader;
		}

		public int ExecuteStoredProcedure(string procedure)
		{
			int rowsAffected = 0;

			//destroy command object if open
			if (m_command !=null)
				m_command.Dispose();

			try
			{
				if (m_dbConnection.State == ConnectionState.Closed)
					m_dbConnection.Open();	

				//create command object
				m_command = new OleDbCommand(procedure,m_dbConnection);
				m_command.CommandType = CommandType.StoredProcedure;
				m_command.CommandTimeout = COMMAND_TIMEOUT;

				//execute query
				rowsAffected = m_command.ExecuteNonQuery();
			}
			catch(Exception sqlException)
			{
				//Util.WriteLog("TIMEOUT",strSQL);
				//destroy command object if open
				if (m_command !=null)
					m_command.Dispose();
				
				throw (sqlException);				
			}

			return rowsAffected;
		}

		/// <summary>
		/// Function Name : ExecuteNonQuery
		/// <param>       : string strSQL</param>
		/// <returns>     : int</returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function is used to return the number of 
		///					rows affected after a dml statement
		/// Modifications : 
		/// </summary>
		public int ExecuteNonQuery(string strSQL)
		{
			int rowsAffected = 0;

			//destroy command object if open
			if (m_command !=null)
				m_command.Dispose();

			try
			{
				//create command object
				m_command = new OleDbCommand(strSQL,m_dbConnection);
				m_command.CommandTimeout = 60;

				//execute query
				rowsAffected = m_command.ExecuteNonQuery();

			}
			catch(OleDbException sqlException)
			{
				//destroy command object if open
				if (m_command !=null)
					m_command.Dispose();
				
				throw (sqlException);				
			}

			return rowsAffected;
		}

		/// <summary>
		/// Function Name : ExecuteNonQuery
		/// <param>       : string strSQL,OleDbCommand command</param>
		/// <returns>     : </returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function is used to execute a dml statement
		/// Modifications : 
		/// </summary>
		public int ExecuteNonQuery(string strSQL,OleDbCommand command)
		{
			int rowsAffected = 0;
			try
			{
				command.CommandText = (strSQL);
				command.CommandTimeout = 180;
				command.Connection = m_dbConnection;
				rowsAffected = command.ExecuteNonQuery();
			}
			catch(OleDbException sqlException)
			{
				throw (sqlException);				
			}

			return rowsAffected;
		}



		/// <summary>
		/// Function Name : ExecuteDataSet
		/// <param>       : string strSQL,string tableName</param>
		/// <returns>     : DataSet</returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function is used to execute a dataset
		/// Modifications : 
		/// </summary>
		public DataSet ExecuteDataSet(string SqlQuery, string tableName)
		{   
			//destroy existing data adapter if any open
			if (m_DataAdapter !=null)
				m_DataAdapter.Dispose();

			//destroy existing dataset if any open
			if (m_DataSet !=null)
				m_DataSet.Dispose();

			try
			{
				m_DataAdapter = new OleDbDataAdapter((SqlQuery), m_dbConnection);
				m_DataSet = new DataSet();
				m_DataAdapter.Fill(m_DataSet,tableName); 
			}
			catch(OleDbException sqlException)
			{
				//destroy existing data adapter if any open
				if (m_DataAdapter !=null)
					m_DataAdapter.Dispose();

				//destroy existing dataset if any open
				if (m_DataSet !=null)
					m_DataSet.Dispose();

				throw (sqlException);				
			}

			return m_DataSet;
		}

		/// <summary>
		/// Function Name : ExecuteDataSet
		/// <param>       : string strSQL,string tableName</param>
		/// <returns>     : string errMessage,DataSet</returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function is used to execute and return dataset
		///					and generate an error msg if unable to do so
		/// Modifications : 
		/// </summary>

		public DataSet ExecuteDataSet(string SqlQuery, string tableName, out string errMessage)
		{   
			errMessage = "";
			//destroy existing data adapter if any open
			if (m_DataAdapter !=null)
				m_DataAdapter.Dispose();

			//destroy existing dataset if any open
			if (m_DataSet !=null)
				m_DataSet.Dispose();

			try
			{
				m_DataAdapter = new OleDbDataAdapter((SqlQuery), m_dbConnection);
				m_DataSet = new DataSet();
				m_DataAdapter.Fill(m_DataSet,tableName); 
				if (m_DataSet.Tables[0].Rows.Count ==0 )
				{
					errMessage = "Dataset is empty.";
				}
			}
			catch(OleDbException sqlException)
			{
				//destroy existing data adapter if any open
				if (m_DataAdapter !=null)
					m_DataAdapter.Dispose();

				//destroy existing dataset if any open
				if (m_DataSet !=null)
					m_DataSet.Dispose();

				throw (sqlException);				
			}

			return m_DataSet;
		}

		/// <summary>
		/// Function Name : ExecuteDataSet
		/// <param>       : OleDbDataAdapter da</param>
		/// <returns>     : DataSet</returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function is used to execute and return dataset
		///					with dataadapter as the param
		/// Modifications : 
		/// </summary>

		public DataSet ExecuteDataSet(OleDbDataAdapter da)
		{   
			//destroy existing dataset if any open
			if (m_DataSet !=null)
				m_DataSet.Dispose();

			try
			{
				//m_DataAdapter = new OleDbDataAdapter(SqlQuery, m_dbConnection);
				m_DataSet = new DataSet();
				da.Fill(m_DataSet); 
			}
			catch(OleDbException sqlException)
			{
				//destroy existing dataset if any open
				if (m_DataSet !=null)
					m_DataSet.Dispose();

				throw (sqlException);				
			}

			return m_DataSet;
		}
		
		/// <summary>
		/// Function Name : ExecuteDatatable
		/// <param>       : string SqlQuery, string tableName</param>
		/// <returns>     : DataTable</returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function is used to execute a singlr table and return it
		/// Modifications : 
		/// </summary>

		public DataTable ExecuteDatatable(string SqlQuery, string tableName)
		{   
			//destroy existing data adapter if any open
			if (m_DataAdapter !=null)
				m_DataAdapter.Dispose();

			//destroy existing dataset if any open
			if (m_DataTable !=null)
				m_DataTable.Dispose();

			try
			{
				m_DataAdapter = new OleDbDataAdapter((SqlQuery), m_dbConnection);
				m_DataTable = new DataTable(tableName);
				m_DataAdapter.Fill(m_DataTable); 
			}
			catch(OleDbException sqlException)
			{
				//destroy existing data adapter if any open
				if (m_DataAdapter !=null)
					m_DataAdapter.Dispose();

				//destroy existing dataset if any open
				if (m_DataTable !=null)
					m_DataTable.Dispose();

				throw (sqlException);				
			}

			return m_DataTable;
		}


		public DataTable ExecuteDatatableWithSchema(string SqlQuery, string tableName)
		{
			//destroy existing data adapter if any open
			if (m_DataAdapter !=null)
				m_DataAdapter.Dispose();

			//destroy existing dataset if any open
			if (m_DataTable !=null)
				m_DataTable.Dispose();

			try
			{
				m_DataAdapter = new OleDbDataAdapter((SqlQuery), m_dbConnection);
				m_DataTable = new DataTable(tableName);
				m_DataAdapter.Fill(m_DataTable);
				m_DataAdapter.FillSchema(m_DataTable,SchemaType.Source);


			}
			catch(OleDbException sqlException)
			{
				//destroy existing data adapter if any open
				if (m_DataAdapter !=null)
					m_DataAdapter.Dispose();

				//destroy existing dataset if any open
				if (m_DataTable !=null)
					m_DataTable.Dispose();

				throw (sqlException);
			}

			return m_DataTable;
		}


		/// <summary>
		/// Function Name : ExecuteScalar
		/// <param>       : string strSQL</param>
		/// <returns>     : string</returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : 
		/// Modifications : 
		/// </summary>


		public string ExecuteScalar(string strSQL)
		{
			string scalarVal = "";
			//close command if already open
			if (m_command !=null)
				m_command.Dispose();
			
			try
			{
				//create command object
				m_command = new OleDbCommand((strSQL),m_dbConnection);

				//execute command and get value
				if (m_command.ExecuteScalar() != null)
				{
					scalarVal = m_command.ExecuteScalar().ToString();
				}
			}
			catch(OleDbException sqlException)
			{
				if (m_command !=null)
					m_command.Dispose();

				throw (sqlException);
			}
			return scalarVal;
			
		}

		public string ExecuteScalar(string strSQL, OleDbCommand command)
		{
			string scalarVal = "";
			
			try
			{
				command.CommandText = (strSQL);
				command.Connection = m_dbConnection;
				scalarVal = command.ExecuteScalar().ToString();
			}
			catch(OleDbException sqlException)
			{
				throw (sqlException);
			}
			return scalarVal;
		}


		/// <summary>
		/// Function Name : CloseDB
		/// <param>       : </param>
		/// <returns>     : </returns>
		/// Author        : Anand Jha
		/// Date Created  : //
		/// Date Modified : //
		/// Description   : This function handles the closing of the connection
		/// Modifications : 
		/// </summary>

		public void CloseDB()
		{			
			//close reader
			if (m_reader !=null)
				m_reader.Close();

			//destroy command object
			if (m_command !=null)
				m_command.Dispose();

			//destroy transaction object
			if (m_Transaction != null)
			{
				m_Transaction.Rollback();
				m_Transaction = null;
			}

			//close connection
			m_dbConnection.Close();			
		}		
	}

    public class AppInfo
    {
        private static string sApplicationPath;
        private static string sConnectionString;
        private static string sSqlConnectionString;
        private static string sApplicationTitle;

        public AppInfo()
        {
            //
            // TODO: Add constructor logic here
            //
        }

        public static string ApplicationPath
        {
            get
            {
                return sApplicationPath;
            }
        }

        public static string ConnectionString
        {
            get
            {
                return sConnectionString;
            }
        }

        public static string SqlConnectionString
        {
            get
            {
                return sSqlConnectionString;
            }
        }

        public static string ApplicationTitle
        {
            get
            {
                return sApplicationTitle;
            }
        }


        public static void Initialize()
        {
            try
            {
                string appPath = Application.StartupPath + "\\";
                appPath = appPath.Replace("\\bin\\Debug", "");
                appPath = appPath.Replace("\\bin\\Release", "");
                sApplicationPath = appPath;

                AppSettingsReader appCon = new AppSettingsReader();
                string DBMachineName = appCon.GetValue("DBMachineName", typeof(String)).ToString();
                string DBName = appCon.GetValue("DBName", typeof(String)).ToString();
                string DBUserID = appCon.GetValue("DBUserID", typeof(String)).ToString();
                string DBPassword = appCon.GetValue("DBPassword", typeof(String)).ToString();

               

                sConnectionString = "Provider=SQLOLEDB.1;Password=" + DBPassword + ";User ID=" + DBUserID + ";Initial Catalog=" + DBName + ";Data Source=" + DBMachineName; //+ ";Use Procedure for Prepare=1;Auto Translate=True;Packet Size=4096;Workstation ID=DIGIREBAL;Use Encryption for Data=False;Tag with column collation when possible=False;Persist Security Info=True;";
                sSqlConnectionString = "Password=" + DBPassword + ";User ID=" + DBUserID + ";Initial Catalog=" + DBName + ";Data Source=" + DBMachineName;
                sApplicationTitle = "Intelligent Rebalancer";

                //SaveSetting("test", "anand",Application.StartupPath + "\\" + "iRebalClient.exe.config");
            }
            catch
            {
                MessageBox.Show("Could not initialize the application", "ERROR", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}